

 # this is intended for examples,
 # which typically means CODE examples
 such a block
 may contain anything
 - special characters
 are detected and should be guarded: \>.

 # this is another block - coming versions
 # will combine it with the previous one.

-

 # this block ends with the file,
 # there is no trailing newline