
=A simple headline, 1st level

==2nd level

===3rd level

==============================30th level




=Single line

==Multiple
 line

===Multiple
===line (should be detected as ONE paragraph)

====Really
heavy
   multiple
 headline
                                   (all lines complete the SAME paragraph)


=No trailing whitespace

==A trailing whitespace 

===Several trailing whitespaces                                     

====A final simple headline (without final carriage return ...)