
+RED:\FONT{color=red}<__body__>

+F:\FONT{color=__c__}<__body__>

+IB:\I<\B<__body__>>

This \IB<text> is \RED<colored>.

+HTML:\EMBED{lang=html}

+TEXT:Macros can be used to abbreviate longer
texts as well as other tags
or tag combinations.

Tags can be \RED<\I<nested>> into macros. And \I<\RED<vice versa>>.
\IB<\F{c=blue}<This>> is formatted by nested macros.
\HTML This is <i>embedded HTML</i>\END_EMBED.

\TEXT